\name{edge.nls}
\alias{edge.nls}

\title{ Non-Linear Least Squares for Edge Data }

\description{
     Fit a set of edges and observations at focal points to estimate the parameters of the point edge effect function.
}

\usage{
     edge.nls(edgelist, observed, guess, ...)
}

\arguments{
     \item{edgelist}{A list of dataframes, each giving focal point and edge coordinates.  Or a dataframe with equivalent information, as produced by, e.g., \code{\link{relocate.edge.df}}.}
     \item{observed}{A vector of observed response values, one for each focal point.}
     \item{guess}{A list containing the initial guess at the parameter values.}
     \item{...}{Additional arguments to be passed to \code{nls}.}
}

\details{
     Each element of \code{edgelist} gives coordinates of the edges relevant to a focal point.
     Each of these elements is a dataframe with these features:
     \itemize{
          \item The first four columns are used.
          \item The first row is for the focal point, giving its x and y coordinates in the first two columns.
          \item Each additional row is for an edge segment, giving the coordinates of one end (first two columns) and the other end (second two columns).
     }

    The components of \code{guess} are:
    \describe{
      \item{e0}{The maximum effect (at distance 0)}
      \item{k}{The baseline value (at large distance)}
      \item{Dmax}{The maximum distance at which any effect is felt}
      \item{D0}{The distance out to which the maximum effect is felt.  If omitted, its value will be fixed to 0.}
    }

    The call to \code{nls} uses \code{algorithm="port"} and \code{lower=list(e0=-Inf, Dmax=0, k=-Inf, D0=0)} to ensure that Dmax and D0 are non-negative.
}

\value{
     An \code{nls} object
}

\note{
    See \code{vignette("edgefx")} for an example.
}

\references{
    Malcolm (1994) Ecology 75:2438--2445

    Ries etc.
}

\author{
    Goldberg, E.E. and Ries, L.

    Maintainer: Emma E. Goldberg <eeg@uic.edu>
}

\examples{
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (edgelist, observed, guess, ...)
{
    if (class(edgelist) == "list")
    {
        edges <- relocate.edge.df(edgelist)
    } else
    {
        edges <- edgelist
    }

    xvals <- edges[,1]

    if (is.null(guess$D0))
    {
        edge.formula <- formula(observed ~ by(edges[,2:4], xvals, 
                               map.edge.effect, e0, Dmax, k)[xvals])
    } else
    {
        edge.formula <- formula(observed ~ by(edges[,2:4], xvals, 
                               map.edge.effect, e0, Dmax, k, D0)[xvals])
    }

    fit <- nls(edge.formula, start=guess, algorithm="port", 
              lower=list(e0=-Inf, Dmax=0, k=-Inf, D0=0), ...)
    return(fit)

}
}
