\name{grid.edge.effect}
\alias{grid.edge.effect}

\title{ Compute Edge Effect a Specified Grid Cells }

\description{
     For each cell in a list of focal cells, compute its response value, incorporating the effects of all edge cells.
}
\usage{
     grid.edge.effect(focal, edges, map, param)
}

\arguments{
     \item{focal}{A matrix or dataframe of focal cell coordinates.  Each row is a focal cell, the first column is its row coordinate and the second column is its column coordinate.}
     \item{edges}{A dataframe with one row per edge cell.  The columns \code{row} and \code{col} give the coordinates.  Can be produced with \code{\link{find.edges}}.}
     \item{map}{A matrix with one number per cell.  0 is non-habitat, numbers greater than 0 are habitat.}
    \item{param}{A list of parameter values for the plateau point edge effect function.}
}

\details{
    The components of \code{param} are:
    \describe{
      \item{e0}{The maximum effect (at distance 0)}
      \item{k}{The baseline value (at large distance) (not actually required here)}
      \item{Dmax}{The maximum distance at which any effect is felt}
      \item{D0}{The distance out to which the maximum effect is felt}
    }
}

\value{
     A vector with one item per focal cell, in the same order as the focal cell matrix.  Non-habitat cells get \code{NA}.
}

\note{
     This step can be slow for a large grid and large values of \code{Dmax}.
    See \code{vignette("edgefx")} for an example.
}

\references{
    Malcolm (1994) Ecology 75:2438--2445

    Ries etc.
}

\author{
    Goldberg, E.E. and Ries, L.

    Maintainer: Emma E. Goldberg <eeg@uic.edu>
}

\examples{
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (focal, edges, map, param) 
{
    if (class(focal) != "data.frame") {
        focal <- data.frame(row = focal[1], col = focal[2])
    }
    if (map[focal$row, focal$col] == 0) {
        return(NA)
    }
    else {
        dx <- param$Dmax
        near.edges <- edges[edges$row \%in\% seq(focal$row - dx, 
            focal$row + dx) & edges$col \%in\% seq(focal$col - 
            dx, focal$col + dx), ]
        distances <- apply(near.edges, 1, distance, focal)
        distances <- distances[distances < param$Dmax]
        if (length(distances) == 0) {
            return(param$k)
        }
        else {
            edge.effects <- sapply(distances, cell.edge.effect, 
                param)
            return(sum(edge.effects) + param$k)
        }
    }
  }
}
