\name{grid.effects}
\alias{grid.effects}

\title{ Compute Edge Effect at Each Grid Cell }

\description{
     Treat each habitat cell in turn as the focal cell and compute its response value, incorporating the effects of all edge cells.
}

\usage{
     grid.effects(map, edges, param)
}

\arguments{
     \item{map}{A matrix with one number per cell.  0 is non-habitat, numbers greater than 0 are habitat.}
     \item{edges}{A dataframe with one row per edge cell.  The columns \code{row} and \code{col} give the coordinates.  Can be produced with \code{\link{find.edges}}.}
    \item{param}{A list of parameter values for the plateau point edge effect function.}
}

\details{
    The components of \code{param} are:
    \describe{
      \item{e0}{The maximum effect (at distance 0)}
      \item{k}{The baseline value (at large distance) (not actually required here)}
      \item{Dmax}{The maximum distance at which any effect is felt}
      \item{D0}{The distance out to which the maximum effect is felt}
    }
}

\value{
     A vector with one item per cell, ordered by column (read down column 1, then read down column 2, etc.).  Non-habitat cells get \code{NA}.
}

\note{
     This step can be slow for a large grid and large values of \code{Dmax}.
    See \code{vignette("edgefx")} for an example.
}

\references{
    Malcolm (1994) Ecology 75:2438--2445

    Ries etc.
}

\author{
    Goldberg, E.E. and Ries, L.

    Maintainer: Emma E. Goldberg <eeg@uic.edu>
}

\examples{
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
grid.effects <- function(map, edges, params)
{
    focals <- data.frame(which(map>=0, arr.ind=T))
    edgeff <- apply(focals, 1, grid.edge.effect, edges, map, params)

    return(edgeff)
}
}
