\name{infinite.edge.effect}
\alias{infinite.edge.effect}

\title{ Point Edge Effect Function }

\description{
    Compute the effect of an infinitely long edge at another location (the focal point).
}

\usage{
    infinite.edge.effect(d, e0, Dmax=NULL, k=NULL, D0=0)
}

\arguments{
    \item{d}{The (perpendicular) distance between the edge and the focal point.}
    \item{e0}{A scalar value for the parameter \code{e0}, or a vector or list of all parameters.  See Details.}
    \item{Dmax}{A scalar value for the parameter \code{Dmax}; see Details.}
    \item{k}{A scalar value for the parameter \code{k}; see Details.}
    \item{D0}{A scalar value for the parameter \code{D0}; see Details.}
}

\details{
     If \code{e0} is a scalar value, the remaining three arguments are used.  But it can also be a list or a vector containing elements \code{e0}, \code{Dmax}, \code{k}, and optionally \code{D0}.  If the vector elements are unnamed, they are assumed to be in that order.  If a list or a vector is given as the second argument, the last three arguments are ignored.
}

\value{
    A scalar.
}

\note{
    See \code{vignette("edgefx")} for examples.
}

\references{
    Malcolm (1994) Ecology 75:2438--2445

    Ries etc.
}

\author{
    Goldberg, E.E. and Ries, L.

    Maintainer: Emma E. Goldberg <eeg@uic.edu>
}

\examples{
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (d, e0, Dmax=NULL, k=NULL, D0=0) 
{
    if (length(d) != 1)
    {
        stop("distance argument must be a scalar")
    }

    if (length(e0) == 1)
    {
        if (is.null(Dmax) || is.null(k))
            stop("invalid parameter specification")
    } else   # "e0" could actually be a list or vector of all parameters
    {
        params <- unlist(e0)
        if (is.null(names(params)))
            names(params) <- c("e0", "Dmax", "k", "D0")[1:length(params)]

        e0 <- params["e0"]
        Dmax <- params["Dmax"]
        k <- params["k"]
        D0 <- params["D0"]
        if (is.na(D0))  D0 <- 0
        names(e0) <- names(Dmax) <- names(k) <- names(D0) <- NULL
    }

    p <- rbind(c(d, 0), c(0, -Inf), c(0, Inf))
    return(segment.edge.effect(p, e0, Dmax, D0) + k)
}
}
