\name{point.edge.effect}
\alias{point.edge.effect}

\title{ Point Edge Effect Function }

\description{
    Compute the effect of a very small amount of edge (a point source) at another location (the focal point).
}

\usage{
    point.edge.effect(d, param)
}

\arguments{
    \item{d}{The distance between the edge point source and the focal point}
    \item{param}{A list of parameter values for the plateau point edge effect function (see below)}
}

\details{
    The components of \code{param} are:
    \describe{
      \item{e0}{The maximum effect (at distance 0)}
      \item{k}{The baseline value (at large distance) (not actually used here)}
      \item{Dmax}{The maximum distance at which any effect is felt}
      \item{D0}{The distance out to which the maximum effect is felt}
    }
}

\value{
    A scalar.
}

\note{
    See \code{vignette("edgefx")} for the actual function.
}

\references{
    Malcolm (1994) Ecology 75:2438--2445

    Ries etc.
}

\author{
    Goldberg, E.E. and Ries, L.

    Maintainer: Emma E. Goldberg <eeg@uic.edu>
}

\examples{
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (d, param) 
{
    if (length(d) != 1) {
        stop("distance argument must be a scalar")
    }
    if (d < 0) {
        warning("negative distance; using absolute value")
        d <- -d
    }
    if (d <= param$D0) {
        return(p$e0)
    }
    else if (d <= param$Dmax) {
        return(param$e0 * (1 + (param$D0 - d)/(param$Dmax - param$D0)))
    }
    else {
        return(0)
    }
  }
}
