\name{relocate.edge.df}
\alias{relocate.edge.df}

\title{Relocate Edges to Standard Coordinates}

\description{
     For each focal point--edge pair, rotate and translate them so that the focal point is on the positive x axis and the edge lies along the y axis.
}

\usage{
relocate.edge.df(edgelist)
}

\arguments{
     \item{edgelist}{A list of dataframes, each giving focal point and edge coordinates.}
}

\details{
     Each element of \code{edgelist} gives coordinates of the edges relevant to a focal point.
     Each of these elements is a dataframe with these features:
     \itemize{
          \item The first four columns are used.
          \item The first row is for the focal point, giving its x and y coordinates in the first two columns.
          \item Each additional row is for an edge segment, giving the coordinates of one end (first two columns) and the other end (second two columns).
     }
}

\value{
     A dataframe with one row for each focal point--edge pair.  The columns are:
     \item{map}{The name of the map containing the focal point--edge pair}
     \item{x0}{The x coordinate of the focal point (its y value is 0)}
     \item{y1}{The y coordinate of one end of the edge segment (its x value is 0)}
     \item{y2}{The y coordinate of the other end of the edge segment (its x value is 0)}
}

\note{
    See \code{vignette("edgefx")} for an example.
}

\references{
    Malcolm (1994) Ecology 75:2438--2445

    Ries etc.
}

\author{
    Goldberg, E.E. and Ries, L.

    Maintainer: Emma E. Goldberg <eeg@uic.edu>
}

\examples{
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (edgelist) 
{
    edges.per.map = sapply(edgelist, nrow) - 1
    mapnames = rep(names(edgelist), edges.per.map)
    num.sets = length(mapnames)
    edges1 = matrix(NA, nrow = num.sets, ncol = 3, dimnames = list(c(), 
        c("x0", "y1", "y2")))
    atrow = 0
    for (j in seq(length(edgelist))) {
        dat = edgelist[[j]]
        focal = as.matrix(dat[1, 1:2])
        edges = as.matrix(dat[-1, 1:4])
        ans = apply(edges, 1, relocate.wrapper, focal)
        for (i in seq(ncol(ans))) {
            atrow = atrow + 1
            edges1[atrow, 1:3] = ans[, i]
        }
    }
    edges2 = cbind(mapnames, data.frame(edges1))
    return(edges2)
  }
}
