\name{segment.edge.effect}
\alias{segment.edge.effect}
\title{ Segment Edge Effect Function }

\description{
    Compute the effect of a finite edge at another location (the focal point).
}

\usage{
    segment.edge.effect(p, e0, Dmax, D0)
}

\arguments{
      \item{p}{ A matrix or dataframe with two columns ((x, y) coordinates) and three rows (focal point, edge end, other edge end).  The coordinates must be transformed (via e.g. \code{relocate.edge}) so that p[1][2] = p[2][1] = p[3][1] = 0. }
      \item{e0}{The maximum effect (at distance 0)}
      \item{Dmax}{The maximum distance at which any effect is felt}
      \item{D0}{The distance out to which the maximum effect is felt}
}

\value{
    A scalar.
}

\author{
    Goldberg, E.E. and Ries, L.

    Maintainer: Emma E. Goldberg <eeg@uic.edu>
}

\references{
    Malcolm (1994) Ecology 75:2438--2445

    Ries etc.
}

\note{
      Rather than calling this function directly, you will probably use it through \code{point.edge.effect}, \code{infinite.edge.effect}, or \code{map.edge.effect}.
}

\examples{
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (p, e0, Dmax, D0) 
{
    p0 = p[1, ]
    p1 = p[2, ]
    p2 = p[3, ]
    if (p0[1] < Dmax) {
        yDmax <- sqrt(Dmax^2 - p0[1]^2)
    }
    if (p0[1] >= Dmax || p1[2] == p2[2] || -yDmax > max(p1[2], 
        p2[2]) || yDmax < min(p1[2], p2[2])) {
        answer <- 0
    }
    else if (p0[1] >= D0) {
        yDmax <- sqrt(Dmax^2 - p0[1]^2)
        amin <- max(min(p1[2], p2[2]), -yDmax)
        amax <- min(max(p1[2], p2[2]), yDmax)
        answer <- def.integral(amin, amax, p0[1], e0, D0, Dmax)
    }
    else if (p0[1] < D0) {
        yD0 <- sqrt(D0^2 - p0[1]^2)
        a1min <- max(min(p1[2], p2[2]), -yD0)
        a1max <- min(max(p1[2], p2[2]), yD0)
        yDmax <- sqrt(Dmax^2 - p0[1]^2)
        a2min <- max(min(p1[2], p2[2]), -yDmax)
        a2max <- min(max(p1[2], p2[2]), yDmax)
        answer <- e0 * (a1max - a1min)
        if (a2min < a1min) {
            answer <- answer + def.integral(a2min, a1min, p0[1], 
                e0, D0, Dmax)
        }
        if (a2max > a1max) {
            answer <- answer + def.integral(a1max, a2max, p0[1], 
                e0, D0, Dmax)
        }
    }
    return(answer)
  }
}
